function [X1,X2] = LoadMasks(varargin)        
    if (length(varargin) == 1)
        handles = varargin{1};
        wind = str2double(get(handles.Fit_Window_Tag,'String'));
        lag = str2double(get(handles.Time_Lag_Tag,'String'));
        frames = handles.frames;
        b = handles.b;
        Xlim = handles.XLim;
        Ylim = handles.YLim;
        mFRM = length(frames)-lag;
    elseif (length(varargin) > 1)
        handles = varargin{1};
        wind = str2double(get(handles.Fit_Window_Tag,'String'));
        lag = str2double(get(handles.Time_Lag_Tag,'String'));
        file = varargin{2};
        if file == 0
            X = 0;
            return;
        end
        info = imfinfo(file);
        NUM_ELEMENTS = numel(info);
        if NUM_ELEMENTS>0

            b = cell(1,NUM_ELEMENTS);
            frames= cell(1,NUM_ELEMENTS);
            xmi= zeros(1,NUM_ELEMENTS);
            xma=xmi; ymi=xmi; yma=xmi;

            set(handles.progress1,'Visible','on');
            axes(handles.progress1);
            for k = 1:NUM_ELEMENTS
                cla;
                bx=[0 k k 0 0]/NUM_ELEMENTS;
                by=[0 0 1 1 0];
                fill(bx,by,[.7 .7 .7]);
                set(handles.progress1,'Box','on','XLim',[0 1],'YLim',[0 1],'XTick',[],'YTick',[]);
                pause(0.001);
                image = imread(file, k);
                if length(size(image))==3
                    image=image(:,:,1);
                end
                image = cast(image, 'double');
                image(image>0) = 1;
                if max(image(:))==min(image(:))
                    image=ones(size(image));
                end

                [B,L]=bwboundaries(image,'noholes');
                A=regionprops(logical(image),'Area');
                Area=[A.Area];
                [~,ind]=max(Area);
                if ~isempty(ind)
                    [tmp,~]=regbound(B{ind});
                    L(L~=ind)=0; L(L==ind)=1;
                    image(L==1)=1;image(L~=1)=0;
                    smx=sum(L,1); smy=sum(L,2);
                    xmi(k)=find(smx>0,1,'first');
                    xma(k)=find(smx>0,1,'last');
                    ymi(k)=find(smy>0,1,'first');
                    yma(k)=find(smy>0,1,'last');
                    b{k}=tmp;
                else
                    xmi(k)=Inf;
                    xma(k)=-Inf;
                    ymi(k)=Inf;
                    yma(k)=-Inf;
                end
                frames{k}=image;
            end

            Xlim=[min(xmi)-10 max(xma)+10];
            Ylim=[min(ymi)-10 max(yma)+10];
        end
        mFRM=NUM_ELEMENTS-lag;

    end

    SmXb=cell(1,mFRM+lag);
    SmYb=cell(1,mFRM+lag);

    Bare=zeros(1,mFRM+lag);
    x1Cell = cell(1,mFRM);
    y1Cell = cell(1,mFRM);
    x2Cell = cell(1,mFRM);
    y2Cell = cell(1,mFRM);
    XC=zeros(1,mFRM+lag);              % coordinates of the center of
    YC=zeros(1,mFRM+lag);              % cell (center of mass) 
    XC1=zeros(1,mFRM);       
    YC1=zeros(1,mFRM);           
    KSI=zeros(2,mFRM);
    KSO=zeros(2,mFRM);
    PSI=zeros(2,mFRM);
    PSO=zeros(2,mFRM);
    Vi=zeros(2,mFRM); Vo=zeros(2,mFRM); 
    Ui=zeros(2,mFRM); Uo=zeros(2,mFRM);
    
    P1=zeros(1,mFRM);
    
    set(handles.progress2,'Visible','on');
    axes(handles.progress2);
    for fr=1:mFRM
        cla
        bx=[0 fr fr 0 0]/mFRM;
        by=[0 0 1 1 0];
        fill(bx,by,[.7 .7 .7]);
        set(handles.progress2,'Box','on','XLim',[0 1],'YLim',[0 1],'XTick',[],'YTick',[]);
        pause(0.001);
        F=frames{fr};
        F1 = frames{fr+lag};
        Lbs1 = length(b{fr});
        Lbs2 = length(b{fr+lag});
        [XN1,YN1,~,~] = SmothBound(F,Lbs1,1);
        [XN2,YN2,~,~] = SmothBound(F1,Lbs2,1);


        %-----------------------< in or out >--------------------------
        Mbs=[inf, -inf, inf, -inf];

        in=zeros(1,Lbs2);
        on=zeros(1,Lbs2);
        non=zeros(1,Lbs2);
        ksi=zeros(1,Lbs2);
        kso=zeros(1,Lbs2);
        ssi=zeros(1,Lbs2);
        sso=zeros(1,Lbs2);

        %------------------------< Polarity P3>--------------------------
        
        for i=1:Lbs2
            [in(i),on(i)]=inpolygon(XN2(i),YN2(i),[XN1'; XN1(1)],[YN1'; YN1(1)]);
            non(i)=~on(i);

            DTB = DistToBoundX(XN2(i),YN2(i),XN1,YN1,Mbs);
            ang = 2*pi*i/Lbs2;

            if in(i)==1
                PSI(1,fr)=PSI(1,fr)+DTB*cos(ang);
                PSI(2,fr)=PSI(2,fr)+DTB*sin(ang);
            else
                PSO(1,fr)=PSO(1,fr)+DTB*cos(ang);
                PSO(2,fr)=PSO(2,fr)+DTB*sin(ang);
            end               
        end

        c=(1:Lbs2)/Lbs2;        
        ao=find(in==0);
        bo=length(ao); 
        ai=find(in==1 & on==0);
        bi=length(ai); 

        if bi~=0
            PSI(:,fr)=PSI(:,fr)/bi;
        end
        if bo~=0
            PSO(:,fr)=PSO(:,fr)/bo;
        end


        SmXb{fr}=XN1; SmYb{fr}=YN1;
        %--------------------------< Centroid P1>------------------------
        
        [GX,GY]=meshgrid(1:size(F,2),1:size(F,1));
        MX=F.*GX; MY=F.*GY; Mass=sum(F(:));
        XC(fr)= sum(MX(:))/Mass;
        YC(fr)= sum(MY(:))/Mass;
        
        MX=F1.*GX; MY=F1.*GY; Mass=sum(F1(:));
        XC1(fr)= sum(MX(:))/Mass;
        YC1(fr)= sum(MY(:))/Mass;
        
        P1(fr)=sqrt((XC(fr)-XC1(fr))^2+(YC(fr)-YC1(fr))^2)/lag;
        if (fr >= mFRM - lag)
            XC(fr+lag)=XC1(fr);   YC(fr+lag)=YC(fr);
        end
        
        %--------------------------< New Pol Par P4 >-----------------
        ang=linspace(0,2*pi,Lbs2);
        
        x1Cell{fr}=cos(ang(ai)); y1Cell{fr}=sin(ang(ai));
        x2Cell{fr}=cos(ang(ao)); y2Cell{fr}=sin(ang(ao));
       
        Vi(1,fr)=mean(x1Cell{fr}); Vi(2,fr)=mean(y1Cell{fr});
        Vo(1,fr)=mean(x2Cell{fr}); Vo(2,fr)=mean(y2Cell{fr});

        Ui(1,fr)=pi*sum(x1Cell{fr})/Lbs2; Ui(2,fr)=pi*sum(y1Cell{fr})/Lbs2;
        Uo(1,fr)=pi*sum(x2Cell{fr})/Lbs2; Uo(2,fr)=pi*sum(y2Cell{fr})/Lbs2;        
        
        %-----------------------< Uniformness P2>------------------------
        if bi==0 && bo~=0
            for i=1:Lbs2
                kso(i)=sum(ao<=i)/bo;
            end          
            for i=1:Lbs2
                kkso=[(kso(i:end)-kso(i)) (kso(1:(i-1))+1-kso(i))];
                sso(i)=max(abs(kkso-c));
            end
        elseif bi~=0 && bo==0
            for i=1:Lbs2
                ksi(i)=sum(ai<=i)/bi;
            end
            for i=1:Lbs2
                kksi=[(ksi(i:end)-ksi(i)) (ksi(1:(i-1))+1-ksi(i))];
                ssi(i)=max(abs(kksi-c));
            end            
        else                
            for i=1:Lbs2
                ksi(i)=sum(ai<=i)/bi;
                kso(i)=sum(ao<=i)/bo;
            end
            for i=1:Lbs2
                kksi=[(ksi(i:end)-ksi(i)) (ksi(1:(i-1))+1-ksi(i))];
                kkso=[(kso(i:end)-kso(i)) (kso(1:(i-1))+1-kso(i))];
                ssi(i)=max(abs(kksi-c));
                sso(i)=max(abs(kkso-c));
            end            
        end

        KSI(1,fr)=min(ssi);
        KSI(2,fr)=max(ssi);
        KSO(1,fr)=min(sso);
        KSO(2,fr)=max(sso);

        %-------------------------< Area >-----------------------------
        Bare(fr) = 0.5*sum(XN1(1:(end-1)).*YN1(2:end)-YN1(1:(end-1)).*XN1(2:end)) + 0.5*(XN1(end)*YN1(1)-YN1(end)*XN1(1));
        Bare(fr)=abs(Bare(fr));
        if (fr >= mFRM - lag)
           Bare(fr+lag) =  0.5*sum(XN2(1:(end-1)).*YN2(2:end)-YN2(1:(end-1)).*XN2(2:end)) + 0.5*(XN2(end)*YN2(1)-YN2(end)*XN2(1));
           Bare(fr+lag)=abs(Bare(fr+lag));
        end
        
        SmXb{fr+lag}=XN2; SmYb{fr+lag}=YN2;

    end
    
    if mFRM>1
        
        gs=min(wind,mFRM-1);

        [Bx,By]=GFilterW(1:(mFRM+lag),Bare,gs);
        dB=200*(By((1+lag):end)-By(1:(end-lag)))./(By((1+lag):end)+By(1:(end-lag)));
        dBRaw=200*(Bare((1+lag):end)-Bare(1:(end-lag)))./(Bare((1+lag):end)+Bare(1:(end-lag)));
        
        [P1x,P1y]=GFilterW(1:mFRM,P1,gs); %P1
        
        [Kx,Ky]=GFilterW(1:mFRM,KSO(2,:),gs); %P2

        POL=sqrt(PSO(1,:).^2+PSO(2,:).^2);  % P3
        [Px,Py]=GFilterW(1:mFRM,POL,gs);

        Vpol=sqrt(Vo(1,:).^2+Vo(2,:).^2);
        [Vx,Vy]=GFilterW(1:mFRM,Vpol,gs);

        Upol=sqrt(Uo(1,:).^2+Uo(2,:).^2);  % P4
        [Ux,Uy]=GFilterW(1:mFRM,Upol,gs);
        
        PP5=PSO;
        PP5(1,2:(end-1))=(PSO(1,1:(end-2))+PSO(1,2:(end-1))+PSO(1,3:end))/3; 
        PP5(2,2:(end-1))=(PSO(2,1:(end-2))+PSO(2,2:(end-1))+PSO(2,3:end))/3; 
        PP5(1,1)=(PSO(1,1)+PSO(1,2))/2;
        PP5(2,1)=(PSO(2,1)+PSO(2,2))/2;
        PP5(1,end)=(PSO(1,end-1)+PSO(1,end))/2;
        PP5(2,end)=(PSO(2,end-1)+PSO(2,end))/2;
        P5=sqrt(PP5(1,:).^2+PP5(2,:).^2);              % P5
        [P5x,P5y]=GFilterW(1:mFRM,P5,gs);
        
        PP6=Uo;
        PP6(1,2:(end-1))=(Uo(1,1:(end-2))+Uo(1,2:(end-1))+Uo(1,3:end))/3; 
        PP6(2,2:(end-1))=(Uo(2,1:(end-2))+Uo(2,2:(end-1))+Uo(2,3:end))/3; 
        PP6(1,1)=(Uo(1,1)+Uo(1,2))/2;
        PP6(2,1)=(Uo(2,1)+Uo(2,2))/2;
        PP6(1,end)=(Uo(1,end-1)+Uo(1,end))/2;
        PP6(2,end)=(Uo(2,end-1)+Uo(2,end))/2;
        P6=sqrt(PP6(1,:).^2+PP6(2,:).^2);              % P6 
        [P6x,P6y]=GFilterW(1:mFRM,P6,gs);


    end
        %%{
        save('temp.mat','SmXb','b','SmYb','XC','YC',...
                                'Bare','Bx','By','dB','dBRaw',...
                                'P1','P1x','P1y',...    
                                'KSI','KSO','Kx','Ky',...
                                'PSI','PSO','POL','Px','Py',...
                                'Vpol','Vx','Vy',....
                                'Upol','Ux','Uy',...
                                'PP5','P5','P5x','P5y',...
                                'PP6','P6','P6x','P6y',...
                                'Xlim','Ylim','mFRM','x1Cell','x2Cell','y1Cell','y2Cell','frames','lag','gs');  
        
        if ~handles.unprocessed        
            handles.smo = gs;
            handles.lag = lag;
            handles.SmXb=SmXb;
            handles.SmYb=SmYb;
            handles.dB=dB; handles.Bx=Bx; handles.By=By;
            handles.KRaw = KSO(2,:);
            handles.VRaw = Vpol(:);
            handles.URaw = Upol(:);
            handles.PRaw = POL(:);
            handles.dBRaw = dBRaw;
            handles.P1Raw = P1;
            handles.P5Raw = P5;
            handles.P6Raw = P6; 
            % Ky=Ky; P2
            handles.Kx=Kx; handles.Ky=Ky;
            % Vy=Vy; 
            handles.Vx=Vx; handles.Vy=Vy;
            % Uy=Uy; P4
            handles.Ux=Ux; handles.Uy=Uy;
            % Py=Py; P3
            handles.Px=Px; handles.Py=Py;
            % P1y=P1y;  P1
            handles.P1x=P1x; handles.P1y=P1y;
            % P5y=P5y;  P5
            handles.P5x=P5x; handles.P5y=P5y;
            % P6y=P6y;  P6
            handles.P6x=P6x; handles.P6y=P6y;

            handles.CRvalues = [handles.CrB,handles.CrP1,handles.CrK,handles.CrP,handles.CrU,handles.CrP5,handles.CrP6];
            save_results_as_text('text_temp.txt','',handles);  
        end
        %}
    path = cd;
    file1 = '/temp.mat';
    file2 = '/text_temp.txt';

    X1 = [path file1];
    X2 = [path file2];


